summaryrefslogtreecommitdiffstats
path: root/kopete/protocols/yahoo/libkyahoo/yahooclientstream.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/protocols/yahoo/libkyahoo/yahooclientstream.h')
-rw-r--r--kopete/protocols/yahoo/libkyahoo/yahooclientstream.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/kopete/protocols/yahoo/libkyahoo/yahooclientstream.h b/kopete/protocols/yahoo/libkyahoo/yahooclientstream.h
index 01ca6a2a..6efc307f 100644
--- a/kopete/protocols/yahoo/libkyahoo/yahooclientstream.h
+++ b/kopete/protocols/yahoo/libkyahoo/yahooclientstream.h
@@ -71,19 +71,19 @@ public:
BindConflict // resource in-use
};
- explicit ClientStream(Connector *conn, QObject *parent=0);
+ explicit ClientStream(Connector *conn, TQObject *parent=0);
~ClientStream();
- void connectToServer(const QString& server, bool auth=true);
+ void connectToServer(const TQString& server, bool auth=true);
void accept(); // server
bool isActive() const;
bool isAuthenticated() const;
// login params
- void setUsername(const QString &s);
- void setPassword(const QString &s);
+ void setUsername(const TQString &s);
+ void setPassword(const TQString &s);
- void setLocalAddr(const QHostAddress &addr, Q_UINT16 port);
+ void setLocalAddr(const TQHostAddress &addr, Q_UINT16 port);
void close();
@@ -103,10 +103,10 @@ public:
void write( Transfer* request );
int errorCondition() const;
- QString errorText() const;
+ TQString errorText() const;
// extrahttp://bugs.kde.org/show_bug.cgi?id=85158
/*# void writeDirect(const QString &s); // must be for debug testing*/
void setNoopTime(int mills);
signals:
@@ -124,7 +124,7 @@ private slots:
/**
* collects wire ready outgoing data from the core protocol and sends
*/
- void cp_outgoingData( const QByteArray& );
+ void cp_outgoingData( const TQByteArray& );
/**
* collects parsed incoming data as a transfer from the core protocol and queues
*/
@@ -103,10 +103,10 @@ public:
// extrahttp://bugs.kde.org/show_bug.cgi?id=85158
-/*# void writeDirect(const QString &s); // must be for debug testing*/
+/*# void writeDirect(const TQString &s); // must be for debug testing*/
void setNoopTime(int mills);
signals: